<?php
/*
Plugin Name: FeedBurner Widget
Version: 1.2
Plugin URI: http://dichev.com/blog/webdesign/feedburner-widget-wordpress-plugin/
Description: Adds a sidebar widget to easy customize and display your <a href="http://feedburner.google.com">FeedBurner</a> subscribers stats RSS button.
Author: Alexander Dichev
Author URI: http://dichev.com/
*/

// Put functions into one big function we'll call at the plugins_loaded
// action. This ensures that all required plugin functions are defined.
function widget_feedburner_init() {
	// Check for the required plugin functions. This will prevent fatal
	// errors occurring when you deactivate the dynamic-sidebar plugin.
	if ( !function_exists('register_sidebar_widget') ) {
		return;
    }
	// This is the function that outputs our little FeedBurner chicklet.
	function widget_feedburner($args) {
		// $args is an array of strings that help widgets to conform to
		// the active theme: before_widget, before_title, after_widget,
		// and after_title are the array keys. Default tags: li and h2.
		extract($args);
		// Each widget can store its own options. We keep strings here.
		$options = get_option('widget_feedburner');
		$title = $options['title'];
	    $supported_feedburner_widget_version = 2;
	    // FeedBurner Stats widget options
        $fb_brand = !empty($options['fb_brand'])?$options['fb_brand']:'http://feeds2.feedburner.com/';
        $fb_user = $options['fb_user'];
	    $fb_bg = $options['fb_bg'];
	    $fb_fg = $options['fb_fg'];
	    $fb_anim = $options['fb_anim'];
	    $url_params = $options['url_params'];
	    if ( $url_params == "" ) {
            $url_params = 'bg=' . substr($fb_bg,1) .'&amp;fg=' . substr($fb_fg,1) . '&amp;anim=' . $fb_anim;
	    }
		// These lines generate our output. Widgets can be very complex
		// but as you can see here, they can also be very, very simple.
        echo $before_widget;
		if (!empty($title)) {
            echo $before_title . $title . $after_title;  
        }
        echo "\n" 
           . '<p><a href="'. $fb_brand . $fb_user . '"><img src="' . $fb_brand . '~fc/' . $fb_user . '?' . $url_params . '" height="26" width="88" style="border:0" alt="" /></a></p>' . "\n"
           . '<!-- Generated by FeedBurner Widget (http://dichev.com/blog/webdesign/feedburner-widget-wordpress-plugin/) -->' . "\n\n";
		echo $after_widget;
	}
	// This is the function that outputs the form to let the users edit
	// the widget's settings. It's an optional feature that users cry for.
	function widget_feedburner_control() {
		// Get our options and see if we're handling a form submission.
		$options = get_option('widget_feedburner');
		if ( !is_array($options) )
			$options = array('title'=>'Subscribe to RSS',
                     'fb_brand'=>'http://feeds2.feedburner.com/',
					 'fb_user'=>'', 
					 'fb_bg'=>'#E3DACF',
					 'fb_fg'=>'#345797',
					 'fb_anim'=>'0',
					 'url_params'=>'');
		if ( $_POST['feedburner-stats-submit'] ) {
			// Remember to sanitize and format use input appropriately.
			$options['title'] = strip_tags(stripslashes($_POST['title']));
            $options['fb_brand'] = strip_tags(stripslashes($_POST['fb_brand']));            
			$options['fb_user'] = strip_tags(stripslashes($_POST['fb_user']));			
			$options['fb_bg'] = strip_tags(stripslashes($_POST['fb_bodyColor']));
			$options['fb_fg'] = strip_tags(stripslashes($_POST['fb_textColor']));
			$options['fb_anim'] = strip_tags(stripslashes($_POST['fb_anim']));			
			update_option('widget_feedburner', $options);
		}
		// Be sure you format your options to be valid HTML attributes.
		$title = htmlspecialchars($options['title'], ENT_QUOTES);
        $fb_brand = htmlspecialchars($options['fb_brand'], ENT_QUOTES);
		$fb_user = htmlspecialchars($options['fb_user'], ENT_QUOTES);
		$fb_bg = htmlspecialchars($options['fb_bg'], ENT_QUOTES);
		$fb_fg = htmlspecialchars($options['fb_fg'], ENT_QUOTES);
		$fb_anim = htmlspecialchars($options['fb_anim'], ENT_QUOTES);		
		// Here is our little form segment. Notice that we don't need a
		// complete form. This will be embedded into the existing form.
?>

<div>

    <style type="text/css">
        div.csq { background:transparent; border:none; cursor:pointer; height:10px; width:10px; }
        div#countPreviewDiv { background:<?php echo $fb_bg; ?>; border:solid 1px #444; color:<?php echo $fb_fg; ?>; font:11px Verdana, Arial, sans; text-align:center; height:16px; margin: 10px auto 4px; padding:3px; vertical-align:middle; width:82px; }
        div#fbcolorpick table td { margin:0; padding:0; }
    </style>

    <script type="text/javascript">
        function fbcl(theColor) {
            if (document.getElementById) {
                var circForm = document.forms['widget-controls'];
                var re6 = /#[0-9A-Za-z]{6}/;
                if (!re6.test(theColor)) { return; }
                bodyFld = circForm.fb_radioColor[0];
                txtFld = circForm.fb_radioColor[1];
                pv = document.getElementById("countPreviewDiv");
                if (bodyFld.checked) {		
                    circForm.elements['fb_bodyColor'].value = theColor;
                    pv.style.backgroundColor = theColor;
                } else {
                    circForm.elements['fb_textColor'].value = theColor;
                    pv.style.color = theColor;
                }
            }
        }
    </script>  

    <p><strong>Widget Title</strong></p>
    <p><label for="title">Title text (optional)</label><br />
    <input type="text" name="title" id="title" value="<?php echo $title; ?>" class="widefat" /></p>

    <p><strong>FeedBurner Feed Address</strong></p>
    <p><label for="fb_user">FeedBurner Username</label><br />
    <input type="text" name="fb_user" id="fb_user" value="<?php echo $fb_user; ?>" class="widefat" /><br />
    <small><em>(http://feeds2.feedburner.com/USERNAME)</em></small></p>
    <p><label for="fb_brand">MyBrand (if using this feature)</label><br />
    <input type="text" name="fb_brand" id="fb_brand" value="<?php echo $fb_brand; ?>" class="widefat" /><br />
    <small><em>(http://feeds.yourdomain.com/)</em></small></p>

    <p><strong>Chicklet Style</strong></p>
    <p><input type="radio" name="fb_anim" value="0"<?php echo (($fb_anim='1')?' checked="checked"':''); ?> id="fb_static" /> <label for="fb_static"><img src="http://www.feedburner.com/fb/i/services/feedcount_static.gif" alt="" /> Static</label></p>
    <p><input type="radio" name="fb_anim" value="1"<?php echo (($fb_anim='1')?'':' checked="checked"'); ?> id="fb_animated" /> <label for="fb_animated"><img src="http://www.feedburner.com/fb/i/services/feedcount_anim.gif" alt="" /> Animated</label></p>

    <p><strong>Color Scheme</h5>
    <div id="fbcolorpick">
        <table style="border:0; border-collapse:collapse; margin:0 0 12px 0; padding:0;">
            <tr>
                <td style="background:#000000;"><a href="javascript:fbcl('#000000')"><div class="csq"></div></a></td>
                <td style="background:#000033;"><a href="javascript:fbcl('#000033')"><div class="csq"></div></a></td>
                <td style="background:#000066;"><a href="javascript:fbcl('#000066')"><div class="csq"></div></a></td>
                <td style="background:#000099;"><a href="javascript:fbcl('#000099')"><div class="csq"></div></a></td>
                <td style="background:#0000CC;"><a href="javascript:fbcl('#0000CC')"><div class="csq"></div></a></td>
                <td style="background:#0000FF;"><a href="javascript:fbcl('#0000FF')"><div class="csq"></div></a></td>
                <td style="background:#006600;"><a href="javascript:fbcl('#006600')"><div class="csq"></div></a></td>
                <td style="background:#006633;"><a href="javascript:fbcl('#006633')"><div class="csq"></div></a></td>
                <td style="background:#006666;"><a href="javascript:fbcl('#006666')"><div class="csq"></div></a></td>
                <td style="background:#006699;"><a href="javascript:fbcl('#006699')"><div class="csq"></div></a></td>
                <td style="background:#0066CC;"><a href="javascript:fbcl('#0066CC')"><div class="csq"></div></a></td>
                <td style="background:#0066FF;"><a href="javascript:fbcl('#0066FF')"><div class="csq"></div></a></td>
                <td style="background:#00CC00;"><a href="javascript:fbcl('#00CC00')"><div class="csq"></div></a></td>
                <td style="background:#00CC33;"><a href="javascript:fbcl('#00CC33')"><div class="csq"></div></a></td>
                <td style="background:#00CC66;"><a href="javascript:fbcl('#00CC66')"><div class="csq"></div></a></td>
                <td style="background:#00CC99;"><a href="javascript:fbcl('#00CC99')"><div class="csq"></div></a></td>
                <td style="background:#00CCCC;"><a href="javascript:fbcl('#00CCCC')"><div class="csq"></div></a></td>
                <td style="background:#00CCFF;"><a href="javascript:fbcl('#00CCFF')"><div class="csq"></div></a></td>
            </tr>											
            <tr>
                <td style="background:#003300;"><a href="javascript:fbcl('#003300')"><div class="csq"></div></a></td>
                <td style="background:#003333;"><a href="javascript:fbcl('#003333')"><div class="csq"></div></a></td>
                <td style="background:#003366;"><a href="javascript:fbcl('#003366')"><div class="csq"></div></a></td>
                <td style="background:#003399;"><a href="javascript:fbcl('#003399')"><div class="csq"></div></a></td>
                <td style="background:#0033CC;"><a href="javascript:fbcl('#0033CC')"><div class="csq"></div></a></td>
                <td style="background:#0033FF;"><a href="javascript:fbcl('#0033FF')"><div class="csq"></div></a></td>
                <td style="background:#009900;"><a href="javascript:fbcl('#009900')"><div class="csq"></div></a></td>
                <td style="background:#009933;"><a href="javascript:fbcl('#009933')"><div class="csq"></div></a></td>
                <td style="background:#009966;"><a href="javascript:fbcl('#009966')"><div class="csq"></div></a></td>
                <td style="background:#009999;"><a href="javascript:fbcl('#009999')"><div class="csq"></div></a></td>
                <td style="background:#0099CC;"><a href="javascript:fbcl('#0099CC')"><div class="csq"></div></a></td>
                <td style="background:#0099FF;"><a href="javascript:fbcl('#0099FF')"><div class="csq"></div></a></td>
                <td style="background:#00FF00;"><a href="javascript:fbcl('#00FF00')"><div class="csq"></div></a></td>
                <td style="background:#00FF33;"><a href="javascript:fbcl('#00FF33')"><div class="csq"></div></a></td>
                <td style="background:#00FF66;"><a href="javascript:fbcl('#00FF66')"><div class="csq"></div></a></td>
                <td style="background:#00FF99;"><a href="javascript:fbcl('#00FF99')"><div class="csq"></div></a></td>
                <td style="background:#00FFCC;"><a href="javascript:fbcl('#00FFCC')"><div class="csq"></div></a></td>
                <td style="background:#00FFFF;"><a href="javascript:fbcl('#00FFFF')"><div class="csq"></div></a></td>
            </tr>											
            <tr>
                <td style="background:#330000;"><a href="javascript:fbcl('#330000')"><div class="csq"></div></a></td>
                <td style="background:#330033;"><a href="javascript:fbcl('#330033')"><div class="csq"></div></a></td>
                <td style="background:#330066;"><a href="javascript:fbcl('#330066')"><div class="csq"></div></a></td>
                <td style="background:#330099;"><a href="javascript:fbcl('#330099')"><div class="csq"></div></a></td>
                <td style="background:#3300CC;"><a href="javascript:fbcl('#3300CC')"><div class="csq"></div></a></td>
                <td style="background:#3300FF;"><a href="javascript:fbcl('#3300FF')"><div class="csq"></div></a></td>
                <td style="background:#336600;"><a href="javascript:fbcl('#336600')"><div class="csq"></div></a></td>
                <td style="background:#336633;"><a href="javascript:fbcl('#336633')"><div class="csq"></div></a></td>
                <td style="background:#336666;"><a href="javascript:fbcl('#336666')"><div class="csq"></div></a></td>
                <td style="background:#336699;"><a href="javascript:fbcl('#336699')"><div class="csq"></div></a></td>
                <td style="background:#3366CC;"><a href="javascript:fbcl('#3366CC')"><div class="csq"></div></a></td>
                <td style="background:#3366FF;"><a href="javascript:fbcl('#3366FF')"><div class="csq"></div></a></td>
                <td style="background:#33CC00;"><a href="javascript:fbcl('#33CC00')"><div class="csq"></div></a></td>
                <td style="background:#33CC33;"><a href="javascript:fbcl('#33CC33')"><div class="csq"></div></a></td>
                <td style="background:#33CC66;"><a href="javascript:fbcl('#33CC66')"><div class="csq"></div></a></td>
                <td style="background:#33CC99;"><a href="javascript:fbcl('#33CC99')"><div class="csq"></div></a></td>
                <td style="background:#33CCCC;"><a href="javascript:fbcl('#33CCCC')"><div class="csq"></div></a></td>
                <td style="background:#33CCFF;"><a href="javascript:fbcl('#33CCFF')"><div class="csq"></div></a></td>
            </tr>											
            <tr>
                <td style="background:#333300;"><a href="javascript:fbcl('#333300')"><div class="csq"></div></a></td>
                <td style="background:#333333;"><a href="javascript:fbcl('#333333')"><div class="csq"></div></a></td>
                <td style="background:#333366;"><a href="javascript:fbcl('#333366')"><div class="csq"></div></a></td>
                <td style="background:#333399;"><a href="javascript:fbcl('#333399')"><div class="csq"></div></a></td>
                <td style="background:#3333CC;"><a href="javascript:fbcl('#3333CC')"><div class="csq"></div></a></td>
                <td style="background:#3333FF;"><a href="javascript:fbcl('#3333FF')"><div class="csq"></div></a></td>
                <td style="background:#339900;"><a href="javascript:fbcl('#339900')"><div class="csq"></div></a></td>
                <td style="background:#339933;"><a href="javascript:fbcl('#339933')"><div class="csq"></div></a></td>
                <td style="background:#339966;"><a href="javascript:fbcl('#339966')"><div class="csq"></div></a></td>
                <td style="background:#339999;"><a href="javascript:fbcl('#339999')"><div class="csq"></div></a></td>
                <td style="background:#3399CC;"><a href="javascript:fbcl('#3399CC')"><div class="csq"></div></a></td>
                <td style="background:#3399FF;"><a href="javascript:fbcl('#3399FF')"><div class="csq"></div></a></td>
                <td style="background:#33FF00;"><a href="javascript:fbcl('#33FF00')"><div class="csq"></div></a></td>
                <td style="background:#33FF33;"><a href="javascript:fbcl('#33FF33')"><div class="csq"></div></a></td>
                <td style="background:#33FF66;"><a href="javascript:fbcl('#33FF66')"><div class="csq"></div></a></td>
                <td style="background:#33FF99;"><a href="javascript:fbcl('#33FF99')"><div class="csq"></div></a></td>
                <td style="background:#33FFCC;"><a href="javascript:fbcl('#33FFCC')"><div class="csq"></div></a></td>
                <td style="background:#33FFFF;"><a href="javascript:fbcl('#33FFFF')"><div class="csq"></div></a></td>
            </tr>											
            <tr>
                <td style="background:#660000;"><a href="javascript:fbcl('#660000')"><div class="csq"></div></a></td>
                <td style="background:#660033;"><a href="javascript:fbcl('#660033')"><div class="csq"></div></a></td>
                <td style="background:#660066;"><a href="javascript:fbcl('#660066')"><div class="csq"></div></a></td>
                <td style="background:#660099;"><a href="javascript:fbcl('#660099')"><div class="csq"></div></a></td>
                <td style="background:#6600CC;"><a href="javascript:fbcl('#6600CC')"><div class="csq"></div></a></td>
                <td style="background:#6600FF;"><a href="javascript:fbcl('#6600FF')"><div class="csq"></div></a></td>
                <td style="background:#666600;"><a href="javascript:fbcl('#666600')"><div class="csq"></div></a></td>
                <td style="background:#666633;"><a href="javascript:fbcl('#666633')"><div class="csq"></div></a></td>
                <td style="background:#666666;"><a href="javascript:fbcl('#666666')"><div class="csq"></div></a></td>
                <td style="background:#666699;"><a href="javascript:fbcl('#666699')"><div class="csq"></div></a></td>
                <td style="background:#6666CC;"><a href="javascript:fbcl('#6666CC')"><div class="csq"></div></a></td>
                <td style="background:#6666FF;"><a href="javascript:fbcl('#6666FF')"><div class="csq"></div></a></td>
                <td style="background:#66CC00;"><a href="javascript:fbcl('#66CC00')"><div class="csq"></div></a></td>
                <td style="background:#66CC33;"><a href="javascript:fbcl('#66CC33')"><div class="csq"></div></a></td>
                <td style="background:#66CC66;"><a href="javascript:fbcl('#66CC66')"><div class="csq"></div></a></td>
                <td style="background:#66CC99;"><a href="javascript:fbcl('#66CC99')"><div class="csq"></div></a></td>
                <td style="background:#66CCCC;"><a href="javascript:fbcl('#66CCCC')"><div class="csq"></div></a></td>
                <td style="background:#66CCFF;"><a href="javascript:fbcl('#66CCFF')"><div class="csq"></div></a></td>
            </tr>											
            <tr>
                <td style="background:#663300;"><a href="javascript:fbcl('#663300')"><div class="csq"></div></a></td>
                <td style="background:#663333;"><a href="javascript:fbcl('#663333')"><div class="csq"></div></a></td>
                <td style="background:#663366;"><a href="javascript:fbcl('#663366')"><div class="csq"></div></a></td>
                <td style="background:#663399;"><a href="javascript:fbcl('#663399')"><div class="csq"></div></a></td>
                <td style="background:#6633CC;"><a href="javascript:fbcl('#6633CC')"><div class="csq"></div></a></td>
                <td style="background:#6633FF;"><a href="javascript:fbcl('#6633FF')"><div class="csq"></div></a></td>
                <td style="background:#669900;"><a href="javascript:fbcl('#669900')"><div class="csq"></div></a></td>
                <td style="background:#669933;"><a href="javascript:fbcl('#669933')"><div class="csq"></div></a></td>
                <td style="background:#669966;"><a href="javascript:fbcl('#669966')"><div class="csq"></div></a></td>
                <td style="background:#669999;"><a href="javascript:fbcl('#669999')"><div class="csq"></div></a></td>
                <td style="background:#6699CC;"><a href="javascript:fbcl('#6699CC')"><div class="csq"></div></a></td>
                <td style="background:#6699FF;"><a href="javascript:fbcl('#6699FF')"><div class="csq"></div></a></td>
                <td style="background:#66FF00;"><a href="javascript:fbcl('#66FF00')"><div class="csq"></div></a></td>
                <td style="background:#66FF33;"><a href="javascript:fbcl('#66FF33')"><div class="csq"></div></a></td>
                <td style="background:#66FF66;"><a href="javascript:fbcl('#66FF66')"><div class="csq"></div></a></td>
                <td style="background:#66FF99;"><a href="javascript:fbcl('#66FF99')"><div class="csq"></div></a></td>
                <td style="background:#66FFCC;"><a href="javascript:fbcl('#66FFCC')"><div class="csq"></div></a></td>
                <td style="background:#66FFFF;"><a href="javascript:fbcl('#66FFFF')"><div class="csq"></div></a></td>
            </tr>											
            <tr>
                <td style="background:#990000;"><a href="javascript:fbcl('#990000')"><div class="csq"></div></a></td>
                <td style="background:#990033;"><a href="javascript:fbcl('#990033')"><div class="csq"></div></a></td>
                <td style="background:#990066;"><a href="javascript:fbcl('#990066')"><div class="csq"></div></a></td>
                <td style="background:#990099;"><a href="javascript:fbcl('#990099')"><div class="csq"></div></a></td>
                <td style="background:#9900CC;"><a href="javascript:fbcl('#9900CC')"><div class="csq"></div></a></td>
                <td style="background:#9900FF;"><a href="javascript:fbcl('#9900FF')"><div class="csq"></div></a></td>
                <td style="background:#996600;"><a href="javascript:fbcl('#996600')"><div class="csq"></div></a></td>
                <td style="background:#996633;"><a href="javascript:fbcl('#996633')"><div class="csq"></div></a></td>
                <td style="background:#996666;"><a href="javascript:fbcl('#996666')"><div class="csq"></div></a></td>
                <td style="background:#996699;"><a href="javascript:fbcl('#996699')"><div class="csq"></div></a></td>
                <td style="background:#9966CC;"><a href="javascript:fbcl('#9966CC')"><div class="csq"></div></a></td>
                <td style="background:#9966FF;"><a href="javascript:fbcl('#9966FF')"><div class="csq"></div></a></td>
                <td style="background:#99CC00;"><a href="javascript:fbcl('#99CC00')"><div class="csq"></div></a></td>
                <td style="background:#99CC33;"><a href="javascript:fbcl('#99CC33')"><div class="csq"></div></a></td>
                <td style="background:#99CC66;"><a href="javascript:fbcl('#99CC66')"><div class="csq"></div></a></td>
                <td style="background:#99CC99;"><a href="javascript:fbcl('#99CC99')"><div class="csq"></div></a></td>
                <td style="background:#99CCCC;"><a href="javascript:fbcl('#99CCCC')"><div class="csq"></div></a></td>
                <td style="background:#99CCFF;"><a href="javascript:fbcl('#99CCFF')"><div class="csq"></div></a></td>
            </tr>											
            <tr>
                <td style="background:#993300;"><a href="javascript:fbcl('#993300')"><div class="csq"></div></a></td>
                <td style="background:#993333;"><a href="javascript:fbcl('#993333')"><div class="csq"></div></a></td>
                <td style="background:#993366;"><a href="javascript:fbcl('#993366')"><div class="csq"></div></a></td>
                <td style="background:#993399;"><a href="javascript:fbcl('#993399')"><div class="csq"></div></a></td>
                <td style="background:#9933CC;"><a href="javascript:fbcl('#9933CC')"><div class="csq"></div></a></td>
                <td style="background:#9933FF;"><a href="javascript:fbcl('#9933FF')"><div class="csq"></div></a></td>
                <td style="background:#999900;"><a href="javascript:fbcl('#999900')"><div class="csq"></div></a></td>
                <td style="background:#999933;"><a href="javascript:fbcl('#999933')"><div class="csq"></div></a></td>
                <td style="background:#999966;"><a href="javascript:fbcl('#999966')"><div class="csq"></div></a></td>
                <td style="background:#999999;"><a href="javascript:fbcl('#999999')"><div class="csq"></div></a></td>
                <td style="background:#9999CC;"><a href="javascript:fbcl('#9999CC')"><div class="csq"></div></a></td>
                <td style="background:#9999FF;"><a href="javascript:fbcl('#9999FF')"><div class="csq"></div></a></td>
                <td style="background:#99FF00;"><a href="javascript:fbcl('#99FF00')"><div class="csq"></div></a></td>
                <td style="background:#99FF33;"><a href="javascript:fbcl('#99FF33')"><div class="csq"></div></a></td>
                <td style="background:#99FF66;"><a href="javascript:fbcl('#99FF66')"><div class="csq"></div></a></td>
                <td style="background:#99FF99;"><a href="javascript:fbcl('#99FF99')"><div class="csq"></div></a></td>
                <td style="background:#99FFCC;"><a href="javascript:fbcl('#99FFCC')"><div class="csq"></div></a></td>
                <td style="background:#99FFFF;"><a href="javascript:fbcl('#99FFFF')"><div class="csq"></div></a></td>
            </tr>											
            <tr>
                <td style="background:#CC0000;"><a href="javascript:fbcl('#CC0000')"><div class="csq"></div></a></td>
                <td style="background:#CC0033;"><a href="javascript:fbcl('#CC0033')"><div class="csq"></div></a></td>
                <td style="background:#CC0066;"><a href="javascript:fbcl('#CC0066')"><div class="csq"></div></a></td>
                <td style="background:#CC0099;"><a href="javascript:fbcl('#CC0099')"><div class="csq"></div></a></td>
                <td style="background:#CC00CC;"><a href="javascript:fbcl('#CC00CC')"><div class="csq"></div></a></td>
                <td style="background:#CC00FF;"><a href="javascript:fbcl('#CC00FF')"><div class="csq"></div></a></td>
                <td style="background:#CC6600;"><a href="javascript:fbcl('#CC6600')"><div class="csq"></div></a></td>
                <td style="background:#CC6633;"><a href="javascript:fbcl('#CC6633')"><div class="csq"></div></a></td>
                <td style="background:#CC6666;"><a href="javascript:fbcl('#CC6666')"><div class="csq"></div></a></td>
                <td style="background:#CC6699;"><a href="javascript:fbcl('#CC6699')"><div class="csq"></div></a></td>
                <td style="background:#CC66CC;"><a href="javascript:fbcl('#CC66CC')"><div class="csq"></div></a></td>
                <td style="background:#CC66FF;"><a href="javascript:fbcl('#CC66FF')"><div class="csq"></div></a></td>
                <td style="background:#CCCC00;"><a href="javascript:fbcl('#CCCC00')"><div class="csq"></div></a></td>
                <td style="background:#CCCC33;"><a href="javascript:fbcl('#CCCC33')"><div class="csq"></div></a></td>
                <td style="background:#CCCC66;"><a href="javascript:fbcl('#CCCC66')"><div class="csq"></div></a></td>
                <td style="background:#CCCC99;"><a href="javascript:fbcl('#CCCC99')"><div class="csq"></div></a></td>
                <td style="background:#CCCCCC;"><a href="javascript:fbcl('#CCCCCC')"><div class="csq"></div></a></td>
                <td style="background:#CCCCFF;"><a href="javascript:fbcl('#CCCCFF')"><div class="csq"></div></a></td>
            </tr>											
            <tr>
                <td style="background:#CC3300;"><a href="javascript:fbcl('#CC3300')"><div class="csq"></div></a></td>
                <td style="background:#CC3333;"><a href="javascript:fbcl('#CC3333')"><div class="csq"></div></a></td>
                <td style="background:#CC3366;"><a href="javascript:fbcl('#CC3366')"><div class="csq"></div></a></td>
                <td style="background:#CC3399;"><a href="javascript:fbcl('#CC3399')"><div class="csq"></div></a></td>
                <td style="background:#CC33CC;"><a href="javascript:fbcl('#CC33CC')"><div class="csq"></div></a></td>
                <td style="background:#CC33FF;"><a href="javascript:fbcl('#CC33FF')"><div class="csq"></div></a></td>
                <td style="background:#CC9900;"><a href="javascript:fbcl('#CC9900')"><div class="csq"></div></a></td>
                <td style="background:#CC9933;"><a href="javascript:fbcl('#CC9933')"><div class="csq"></div></a></td>
                <td style="background:#CC9966;"><a href="javascript:fbcl('#CC9966')"><div class="csq"></div></a></td>
                <td style="background:#CC9999;"><a href="javascript:fbcl('#CC9999')"><div class="csq"></div></a></td>
                <td style="background:#CC99CC;"><a href="javascript:fbcl('#CC99CC')"><div class="csq"></div></a></td>
                <td style="background:#CC99FF;"><a href="javascript:fbcl('#CC99FF')"><div class="csq"></div></a></td>
                <td style="background:#CCFF00;"><a href="javascript:fbcl('#CCFF00')"><div class="csq"></div></a></td>
                <td style="background:#CCFF33;"><a href="javascript:fbcl('#CCFF33')"><div class="csq"></div></a></td>
                <td style="background:#CCFF66;"><a href="javascript:fbcl('#CCFF66')"><div class="csq"></div></a></td>
                <td style="background:#CCFF99;"><a href="javascript:fbcl('#CCFF99')"><div class="csq"></div></a></td>
                <td style="background:#CCFFCC;"><a href="javascript:fbcl('#CCFFCC')"><div class="csq"></div></a></td>
                <td style="background:#CCFFFF;"><a href="javascript:fbcl('#CCFFFF')"><div class="csq"></div></a></td>
            </tr>											
            <tr>
                <td style="background:#FF0000;"><a href="javascript:fbcl('#FF0000')"><div class="csq"></div></a></td>
                <td style="background:#FF0033;"><a href="javascript:fbcl('#FF0033')"><div class="csq"></div></a></td>
                <td style="background:#FF0066;"><a href="javascript:fbcl('#FF0066')"><div class="csq"></div></a></td>
                <td style="background:#FF0099;"><a href="javascript:fbcl('#FF0099')"><div class="csq"></div></a></td>
                <td style="background:#FF00CC;"><a href="javascript:fbcl('#FF00CC')"><div class="csq"></div></a></td>
                <td style="background:#FF00FF;"><a href="javascript:fbcl('#FF00FF')"><div class="csq"></div></a></td>
                <td style="background:#FF6600;"><a href="javascript:fbcl('#FF6600')"><div class="csq"></div></a></td>
                <td style="background:#FF6633;"><a href="javascript:fbcl('#FF6633')"><div class="csq"></div></a></td>
                <td style="background:#FF6666;"><a href="javascript:fbcl('#FF6666')"><div class="csq"></div></a></td>
                <td style="background:#FF6699;"><a href="javascript:fbcl('#FF6699')"><div class="csq"></div></a></td>
                <td style="background:#FF66CC;"><a href="javascript:fbcl('#FF66CC')"><div class="csq"></div></a></td>
                <td style="background:#FF66FF;"><a href="javascript:fbcl('#FF66FF')"><div class="csq"></div></a></td>
                <td style="background:#FFCC00;"><a href="javascript:fbcl('#FFCC00')"><div class="csq"></div></a></td>
                <td style="background:#FFCC33;"><a href="javascript:fbcl('#FFCC33')"><div class="csq"></div></a></td>
                <td style="background:#FFCC66;"><a href="javascript:fbcl('#FFCC66')"><div class="csq"></div></a></td>
                <td style="background:#FFCC99;"><a href="javascript:fbcl('#FFCC99')"><div class="csq"></div></a></td>
                <td style="background:#FFCCCC;"><a href="javascript:fbcl('#FFCCCC')"><div class="csq"></div></a></td>
                <td style="background:#FFCCFF;"><a href="javascript:fbcl('#FFCCFF')"><div class="csq"></div></a></td>
            </tr>											
            <tr>
                <td style="background:#FF3300;"><a href="javascript:fbcl('#FF3300')"><div class="csq"></div></a></td>
                <td style="background:#FF3333;"><a href="javascript:fbcl('#FF3333')"><div class="csq"></div></a></td>
                <td style="background:#FF3366;"><a href="javascript:fbcl('#FF3366')"><div class="csq"></div></a></td>
                <td style="background:#FF3399;"><a href="javascript:fbcl('#FF3399')"><div class="csq"></div></a></td>
                <td style="background:#FF33CC;"><a href="javascript:fbcl('#FF33CC')"><div class="csq"></div></a></td>
                <td style="background:#FF33FF;"><a href="javascript:fbcl('#FF33FF')"><div class="csq"></div></a></td>
                <td style="background:#FF9900;"><a href="javascript:fbcl('#FF9900')"><div class="csq"></div></a></td>
                <td style="background:#FF9933;"><a href="javascript:fbcl('#FF9933')"><div class="csq"></div></a></td>
                <td style="background:#FF9966;"><a href="javascript:fbcl('#FF9966')"><div class="csq"></div></a></td>
                <td style="background:#FF9999;"><a href="javascript:fbcl('#FF9999')"><div class="csq"></div></a></td>
                <td style="background:#FF99CC;"><a href="javascript:fbcl('#FF99CC')"><div class="csq"></div></a></td>
                <td style="background:#FF99FF;"><a href="javascript:fbcl('#FF99FF')"><div class="csq"></div></a></td>
                <td style="background:#FFFF00;"><a href="javascript:fbcl('#FFFF00')"><div class="csq"></div></a></td>
                <td style="background:#FFFF33;"><a href="javascript:fbcl('#FFFF33')"><div class="csq"></div></a></td>
                <td style="background:#FFFF66;"><a href="javascript:fbcl('#FFFF66')"><div class="csq"></div></a></td>
                <td style="background:#FFFF99;"><a href="javascript:fbcl('#FFFF99')"><div class="csq"></div></a></td>
                <td style="background:#FFFFCC;"><a href="javascript:fbcl('#FFFFCC')"><div class="csq"></div></a></td>
                <td style="background:#FFFFFF;"><a href="javascript:fbcl('#FFFFFF')"><div class="csq"></div></a></td>
            </tr>											
        </table>
    </div>
    <p><input type="radio" name="fb_radioColor" value="body" id="fb_radioColor1" checked="checked" /> <label for="fb_radioColor1"><input type="text" name="fb_bodyColor" maxlength="7" value="<?php echo $fb_bg; ?>" onkeyup="document.forms['widget-controls'].fb_radioColor[0].checked=true;fbcl(this.value)" style="width:80px;" /> Body</label></p>
    <p><input type="radio" name="fb_radioColor" value="text" id="fb_radioColor2" /> <label for="fb_radioColor2"><input type="text" name="fb_textColor" maxlength="7" value="<?php echo $fb_fg; ?>" onkeyup="document.forms['widget-controls'].fb_radioColor[1].checked=true;fbcl(this.value)" style="width:80px;" /> Text</label></p>

    <p><strong>FeedBurner Button Settings Preview</strong></p>
    <div id="countPreviewDiv">text</div>
    <input type="hidden" id="feedburner-stats-submit" name="feedburner-stats-submit" value="1" />
    
</div>

<?php
	}
	// This registers our widget so it appears with the other available
	// widgets and can be dragged and dropped into any active sidebars.
	register_sidebar_widget('FeedBurner Stats', 'widget_feedburner');
	// This registers our optional widget control form. Because of this
	// our widget will have a button that reveals a 300x100 pixel form.
	register_widget_control('FeedBurner Stats', 'widget_feedburner_control', 250, 470);
}
// Run our code later in case this loads prior to any required plugins.
add_action('plugins_loaded', 'widget_feedburner_init');
?>